@@ -446,19 +446,12 @@ if ($page == 'admins'
 			}
 
 			$ipaddress = makeoption($lng['admin']['allips'], "-1");
-			$ips = array();
 			$ipsandports_stmt = Database::query("
-				SELECT `id`, `ip` FROM `" . TABLE_PANEL_IPSANDPORTS . "` ORDER BY `ip`, `port` ASC
+				SELECT `id`, `ip` FROM `" . TABLE_PANEL_IPSANDPORTS . "` GROUP BY `ip` ORDER BY `ip` ASC
 			");
 
 			while ($row = $ipsandports_stmt->fetch(PDO::FETCH_ASSOC)) {
-				if (filter_var($row['ip'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV6)) {
-					$row['ip'] = '[' . $row['ip'] . ']';
-				}
-				if (!in_array($row['ip'], $ips)) {
-					$ipaddress.= makeoption($row['ip'], $row['id']);
-					$ips[] = $row['ip'];
-				}
+				$ipaddress.= makeoption($row['ip'], $row['id']);
 			}
 
 			$customers_ul = makecheckbox('customers_ul', $lng['customer']['unlimited'], '-1', false, '0', true, true);
@@ -853,19 +846,12 @@ if ($page == 'admins'
 				}
 
 				$ipaddress = makeoption($lng['admin']['allips'], "-1", $result['ip']);
-				$ips = array();
 				$ipsandports_stmt = Database::query("
-					SELECT `id`, `ip` FROM `" . TABLE_PANEL_IPSANDPORTS . "` ORDER BY `ip`, `port` ASC
+					SELECT `id`, `ip` FROM `" . TABLE_PANEL_IPSANDPORTS . "` GROUP BY `ip` ORDER BY `ip`, `port` ASC
 				");
 
 				while ($row = $ipsandports_stmt->fetch(PDO::FETCH_ASSOC)) {
-					if (filter_var($row['ip'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV6)) {
-						$row['ip'] = '[' . $row['ip'] . ']';
-					}
-					if (!in_array($row['ip'], $ips)) {
-						$ipaddress.= makeoption($row['ip'], $row['id'], $result['ip']);
-						$ips[] = $row['ip'];
-					}
+					$ipaddress.= makeoption($row['ip'], $row['id'], $result['ip']);
 				}
 
 				$result = htmlentities_array($result);
