@@ -42,8 +42,8 @@ if ($action == 'login') {
 			$is_admin = false;
 		} else {
 			$is_admin = true;
-			if ((int)$settings['login']['domain_login'] == 1) {
-				$domainname = $idna_convert->encode(preg_replace(Array('/\:(\d)+$/', '/^https?\:\/\//'), '', $loginname));
+			if ((int)Settings::Get('login.domain_login') == 1) {
+				$domainname = $idna_convert->encode(preg_replace(array('/\:(\d)+$/', '/^https?\:\/\//'), '', $loginname));
 				$stmt = Database::prepare("SELECT `customerid` FROM `" . TABLE_PANEL_DOMAINS . "`
 					WHERE `domain` = :domain"
 				);
@@ -100,7 +100,11 @@ if ($action == 'login') {
 				$uid = 'adminid';
 				$adminsession = '1';
 			} else {
-				redirectTo('index.php', Array('showmessage' => '2'), true);
+				// Log failed login
+				$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => $_SERVER['REMOTE_ADDR']));
+				$rstlog->logAction(LOGIN_ACTION, LOG_WARNING, "Unknown user '" . $loginname . "' tried to login.");
+
+				redirectTo('index.php', array('showmessage' => '2'));
 				exit;
 			}
 		}
@@ -111,19 +115,27 @@ if ($action == 'login') {
 		Database::pexecute($userinfo_stmt, array("loginname" => $loginname));
 		$userinfo = $userinfo_stmt->fetch(PDO::FETCH_ASSOC);
 
-		if ($userinfo['loginfail_count'] >= $settings['login']['maxloginattempts'] && $userinfo['lastlogin_fail'] > (time() - $settings['login']['deactivatetime'])) {
-			redirectTo('index.php', Array('showmessage' => '3'), true);
+		if ($userinfo['loginfail_count'] >= Settings::Get('login.maxloginattempts') && $userinfo['lastlogin_fail'] > (time() - Settings::Get('login.deactivatetime'))) {
+			redirectTo('index.php', array('showmessage' => '3'));
 			exit;
-		} elseif($userinfo['password'] == md5($password)) {
-			// login correct
-			// reset loginfail_counter, set lastlogin_succ
-			$stmt = Database::prepare("UPDATE $table
-				SET `lastlogin_succ`= :lastlogin_succ, `loginfail_count`='0'
-				WHERE `$uid`= :uid"
-			);
-			Database::pexecute($stmt, array("lastlogin_succ" => time(), "uid" => $userinfo[$uid]));
-			$userinfo['userid'] = $userinfo[$uid];
-			$userinfo['adminsession'] = $adminsession;
+		} elseif (validatePasswordLogin($userinfo, $password, $table, $uid)) {
+		    // only show "you're banned" if the login was successfull
+		    // because we don't want to publish that the user does exist
+		    if ($userinfo['deactivated']) {
+		        unset($userinfo);
+		        redirectTo('index.php', array('showmessage' => '5'));
+		        exit;
+		    } else {
+		        // login correct
+		        // reset loginfail_counter, set lastlogin_succ
+		        $stmt = Database::prepare("UPDATE $table
+		              SET `lastlogin_succ`= :lastlogin_succ, `loginfail_count`='0'
+		              WHERE `$uid`= :uid"
+		        );
+		        Database::pexecute($stmt, array("lastlogin_succ" => time(), "uid" => $userinfo[$uid]));
+		        $userinfo['userid'] = $userinfo[$uid];
+		        $userinfo['adminsession'] = $adminsession;
+		    }
 		} else {
 			// login incorrect
 			$stmt = Database::prepare("UPDATE $table
@@ -131,8 +143,13 @@ if ($action == 'login') {
 				WHERE `$uid`= :uid"
 			);
 			Database::pexecute($stmt, array("lastlogin_fail" => time(), "uid" => $userinfo[$uid]));
+
+			// Log failed login
+			$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => $_SERVER['REMOTE_ADDR']));
+			$rstlog->logAction(LOGIN_ACTION, LOG_WARNING, "User '" . $loginname . "' tried to login with wrong password.");
+
 			unset($userinfo);
-			redirectTo('index.php', Array('showmessage' => '2'), true);
+			redirectTo('index.php', array('showmessage' => '2'));
 			exit;
 		}
 
@@ -143,20 +160,20 @@ if ($action == 'login') {
 				$language = validate($_POST['language'], 'language');
 				if ($language == 'profile') {
 					$language = $userinfo['def_language'];
-				} elseif(!isset($languages[$language])) {
-					$language = $settings['panel']['standardlanguage'];
+				} elseif (!isset($languages[$language])) {
+					$language = Settings::Get('panel.standardlanguage');
 				}
 			} else {
-				$language = $settings['panel']['standardlanguage'];
+				$language = Settings::Get('panel.standardlanguage');
 			}
 
 			if (isset($userinfo['theme']) && $userinfo['theme'] != '') {
 				$theme = $userinfo['theme'];
 			} else {
-				$theme = $settings['panel']['default_theme'];
+				$theme = Settings::Get('panel.default_theme');
 			}
 
-			if ($settings['session']['allow_multiple_login'] != '1') {
+			if (Settings::Get('session.allow_multiple_login') != '1') {
 				$stmt = Database::prepare("DELETE FROM `" . TABLE_PANEL_SESSIONS . "`
 					WHERE `userid` = :uid
 					AND `adminsession` = :adminsession"
@@ -190,25 +207,39 @@ if ($action == 'login') {
 					(`hash`, `userid`, `ipaddress`, `useragent`, `lastactivity`, `language`, `adminsession`, `theme`)
 					VALUES (:hash, :userid, :ipaddress, :useragent, :lastactivity, :language, :adminsession, :theme)"
 				);
-    		} else {
-    			$stmt = Database::prepare("INSERT INTO `" . TABLE_PANEL_SESSIONS . "`
+			} else {
+				$stmt = Database::prepare("INSERT INTO `" . TABLE_PANEL_SESSIONS . "`
 					(`hash`, `userid`, `ipaddress`, `useragent`, `lastactivity`, `language`, `adminsession`)
 					VALUES (:hash, :userid, :ipaddress, :useragent, :lastactivity, :language, :adminsession)"
 				);
-    		}
-    		Database::pexecute($stmt, $params);
+			}
+			Database::pexecute($stmt, $params);
+
+			$qryparams = array();
+			if (isset($_POST['qrystr']) && $_POST['qrystr'] != "") {
+				parse_str(urldecode($_POST['qrystr']), $qryparams);
+			}
+			$qryparams['s'] = $s;
 
 			if ($userinfo['adminsession'] == '1') {
 				if (hasUpdates($version)) {
-					redirectTo('admin_updates.php', Array('s' => $s), true);
+					redirectTo('admin_updates.php', array('s' => $s));
 				} else {
-					redirectTo('admin_index.php', Array('s' => $s), true);
+					if (isset($_POST['script']) && $_POST['script'] != "") {
+						redirectTo($_POST['script'], $qryparams);
+					} else {
+						redirectTo('admin_index.php', $qryparams);
+					}
 				}
 			} else {
-				redirectTo('customer_index.php', Array('s' => $s), true);
+				if (isset($_POST['script']) && $_POST['script'] != "") {
+					redirectTo($_POST['script'], $qryparams);
+				} else {
+					redirectTo('customer_index.php', $qryparams);
+				}
 			}
 		} else {
-			redirectTo('index.php', Array('showmessage' => '2'), true);
+			redirectTo('index.php', array('showmessage' => '2'));
 		}
 		exit;
 	} else {
@@ -224,34 +255,51 @@ if ($action == 'login') {
 		$successmessage = '';
 
 		switch ($smessage) {
-			case 1:
-				$successmessage = $lng['pwdreminder']['success'];
-				break;
-			case 2:
-				$message = $lng['error']['login'];
-				break;
-			case 3:
-				$message = sprintf($lng['error']['login_blocked'],$settings['login']['deactivatetime']);
-				break;
-			case 4:
-				$cmail = isset($_GET['customermail']) ? $_GET['customermail'] : 'unknown';
-				$message = str_replace('%s', $cmail, $lng['error']['errorsendingmail']);
-				break;
-			case 5:
-				$message = $lng['error']['user_banned'];
-				break;
-			case 6:
-				$successmessage = $lng['pwdreminder']['changed'];
-				break;
-			case 7:
-				$message = $lng['pwdreminder']['wrongcode'];
-				break;
+		case 1:
+			$successmessage = $lng['pwdreminder']['success'];
+			break;
+		case 2:
+			$message = $lng['error']['login'];
+			break;
+		case 3:
+			$message = sprintf($lng['error']['login_blocked'], Settings::Get('login.deactivatetime'));
+			break;
+		case 4:
+			$cmail = isset($_GET['customermail']) ? $_GET['customermail'] : 'unknown';
+			$message = str_replace('%s', $cmail, $lng['error']['errorsendingmail']);
+			break;
+		case 5:
+			$message = $lng['error']['user_banned'];
+			break;
+		case 6:
+			$successmessage = $lng['pwdreminder']['changed'];
+			break;
+		case 7:
+			$message = $lng['pwdreminder']['wrongcode'];
+			break;
+		case 8:
+		    $message = $lng['pwdreminder']['notallowed'];
+		    break;
 		}
 
 		$update_in_progress = '';
 		if (hasUpdates($version)) {
 			$update_in_progress = $lng['update']['updateinprogress_onlyadmincanlogin'];
 		}
+		
+		// Pass the last used page if needed
+		$lastscript = "";
+		if (isset($_REQUEST['script']) && $_REQUEST['script'] != "") {
+			$lastscript = $_REQUEST['script'];
+
+			if (!file_exists(__DIR__."/".$lastscript)) {
+				$lastscript = "";
+			}
+		}
+		$lastqrystr = "";
+		if (isset($_REQUEST['qrystr']) && $_REQUEST['qrystr'] != "") {
+			$lastqrystr = strip_tags($_REQUEST['qrystr']);
+		}
 
 		eval("echo \"" . getTemplate('login') . "\";");
 	}
@@ -289,18 +337,18 @@ if ($action == 'forgotpwd') {
 
 			/* Check whether user is banned */
 			if ($user['deactivated']) {
-				$message = $lng['pwdreminder']['notallowed'];
-				redirectTo('index.php', Array('showmessage' => '5'), true);
+				redirectTo('index.php', array('showmessage' => '8'));
+				exit;
 			}
 
-			if (($adminchecked && $settings['panel']['allow_preset_admin'] == '1') || $adminchecked == false) {
+			if (($adminchecked && Settings::Get('panel.allow_preset_admin') == '1') || $adminchecked == false) {
 				if ($user !== false) {
 					// build a activation code
 					$timestamp = time();
 					$first = substr(md5($user['loginname'] . $timestamp . rand(0, $timestamp)), 0, 15);
 					$third = substr(md5($user['email'] . $timestamp . rand(0, $timestamp)), -15);
 					$activationcode = $first . $timestamp . $third . substr(md5($third . $timestamp), 0, 10);
-					
+
 					// Drop all existing activation codes for this user
 					$stmt = Database::prepare("DELETE FROM `" . TABLE_PANEL_ACTIVATION . "`
 						WHERE `userid` = :userid
@@ -311,7 +359,7 @@ if ($action == 'forgotpwd') {
 						"admin" => $adminchecked ? 1 : 0
 					);
 					Database::pexecute($stmt, $params);
-					
+
 					// Add new activation code to database
 					$stmt = Database::prepare("INSERT INTO `" . TABLE_PANEL_ACTIVATION . "`
 						(userid, admin, creation, activationcode)
@@ -325,25 +373,32 @@ if ($action == 'forgotpwd') {
 					);
 					Database::pexecute($stmt, $params);
 
-					$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => 'password_reset'), $settings);
+					$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => 'password_reset'));
 					$rstlog->logAction(USR_ACTION, LOG_WARNING, "User '" . $user['loginname'] . "' requested a link for setting a new password.");
-					
+
 					// Set together our activation link
-					$protocol = strpos(strtolower($_SERVER['SERVER_PROTOCOL']),'https') === FALSE ? 'http' : 'https';
-					$host = $_SERVER['HTTP_HOST'];
+					$protocol = empty( $_SERVER['HTTPS'] ) ? 'http' : 'https';
+					// this can be a fixed value to avoid potential exploiting by modifying headers
+					$host = Settings::Get('system.hostname'); // $_SERVER['HTTP_HOST'];
 					$port = $_SERVER['SERVER_PORT'] != 80 ? ':' . $_SERVER['SERVER_PORT'] : '';
-					$script = $_SERVER['SCRIPT_NAME'];
+					// don't add :443 when https is used, as it is default (and just looks weird!)
+					if ($protocol == 'https' && $_SERVER['SERVER_PORT'] == '443') {
+						$port = '';
+					}
+					// there can be only one script to handle this so we can use a fixed value here
+					$script = "/index.php"; // $_SERVER['SCRIPT_NAME'];
+					if (Settings::Get('system.froxlordirectlyviahostname') == 0) {
+						$script = makeCorrectFile("/".basename(__DIR__)."/".$script);
+					}
 					$activationlink = $protocol . '://' . $host . $port . $script . '?action=resetpwd&resetcode=' . $activationcode;
-					
+
 					$replace_arr = array(
 						'SALUTATION' => getCorrectUserSalutation($user),
-						'USERNAME' => $user['loginname'],
+						'USERNAME' => $loginname,
 						'LINK' => $activationlink
 					);
 
-					$body = strtr($lng['pwdreminder']['body'], array('%s' => $user['firstname'] . ' ' . $user['name'], '%a' => $activationlink));
-
-					$def_language = ($user['def_language'] != '') ? $user['def_language'] : $settings['panel']['standardlanguage'];
+					$def_language = ($user['def_language'] != '') ? $user['def_language'] : Settings::Get('panel.standardlanguage');
 					$result_stmt = Database::prepare('SELECT `value` FROM `' . TABLE_PANEL_TEMPLATES . '`
 						WHERE `adminid`= :adminid
 						AND `language`= :lang
@@ -352,7 +407,7 @@ if ($action == 'forgotpwd') {
 					);
 					Database::pexecute($result_stmt, array("adminid" => $user['adminid'], "lang" => $def_language));
 					$result = $result_stmt->fetch(PDO::FETCH_ASSOC);
-					$mail_subject = html_entity_decode(replace_variables((($result['value'] != '') ? $result['value'] : $lng['pwdreminder']['subject']), $replace_arr));
+					$mail_subject = html_entity_decode(replace_variables((($result['value'] != '') ? $result['value'] : $lng['mails']['password_reset']['subject']), $replace_arr));
 
 					$result_stmt = Database::prepare('SELECT `value` FROM `' . TABLE_PANEL_TEMPLATES . '`
 						WHERE `adminid`= :adminid
@@ -362,14 +417,14 @@ if ($action == 'forgotpwd') {
 					);
 					Database::pexecute($result_stmt, array("adminid" => $user['adminid'], "lang" => $def_language));
 					$result = $result_stmt->fetch(PDO::FETCH_ASSOC);
-					$mail_body = html_entity_decode(replace_variables((($result['value'] != '') ? $result['value'] : $body), $replace_arr));
+					$mail_body = html_entity_decode(replace_variables((($result['value'] != '') ? $result['value'] : $lng['mails']['password_reset']['mailbody']), $replace_arr));
 
 					$_mailerror = false;
 					try {
 						$mail->Subject = $mail_subject;
 						$mail->AltBody = $mail_body;
 						$mail->MsgHTML(str_replace("\n", "<br />", $mail_body));
-						$mail->AddAddress($user['email'], $user['firstname'] . ' ' . $user['name']);
+						$mail->AddAddress($user['email'], getCorrectUserSalutation($user));
 						$mail->Send();
 					} catch(phpmailerException $e) {
 						$mailerr_msg = $e->errorMessage();
@@ -380,17 +435,17 @@ if ($action == 'forgotpwd') {
 					}
 
 					if ($_mailerror) {
-						$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => 'password_reset'), $settings);
+						$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => 'password_reset'));
 						$rstlog->logAction(ADM_ACTION, LOG_ERR, "Error sending mail: " . $mailerr_msg);
-						redirectTo('index.php', array('showmessage' => '4', 'customermail' => $user['email']), true);
+						redirectTo('index.php', array('showmessage' => '4', 'customermail' => $user['email']));
 						exit;
 					}
 
 					$mail->ClearAddresses();
-					redirectTo('index.php', array('showmessage' => '1'), true);
+					redirectTo('index.php', array('showmessage' => '1'));
 					exit;
 				} else {
-					$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => 'password_reset'), $settings);
+					$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => 'password_reset'));
 					$rstlog->logAction(USR_ACTION, LOG_WARNING, "User '" . $loginname . "' requested to set a new password, but was not found in database!");
 					$message = $lng['login']['combination_not_found'];
 				}
@@ -403,12 +458,12 @@ if ($action == 'forgotpwd') {
 	}
 
 	if ($adminchecked) {
-		if ($settings['panel']['allow_preset_admin'] != '1') {
+		if (Settings::Get('panel.allow_preset_admin') != '1') {
 			$message = $lng['pwdreminder']['notallowed'];
 			unset ($adminchecked);
 		}
 	} else {
-		if ($settings['panel']['allow_preset'] != '1') {
+		if (Settings::Get('panel.allow_preset') != '1') {
 			$message = $lng['pwdreminder']['notallowed'];
 		}
 	}
@@ -418,27 +473,27 @@ if ($action == 'forgotpwd') {
 
 if ($action == 'resetpwd') {
 	$message = '';
-	
+
 	// Remove old activation codes
 	$stmt = Database::prepare("DELETE FROM `" . TABLE_PANEL_ACTIVATION . "`
 		WHERE creation < :oldest"
 	);
 	Database::pexecute($stmt, array("oldest" => time() - 86400));
-	
+
 	if (isset($_GET['resetcode']) && strlen($_GET['resetcode']) == 50) {
 		// Check if activation code is valid
 		$activationcode = $_GET['resetcode'];
 		$timestamp = substr($activationcode, 15, 10);
 		$third = substr($activationcode, 25, 15);
 		$check = substr($activationcode, 40, 10);
-		
+
 		if (substr(md5($third . $timestamp), 0, 10) == $check && $timestamp >= time() - 86400) {
 			if (isset($_POST['send']) && $_POST['send'] == 'send') {
 				$stmt = Database::prepare("SELECT `userid`, `admin` FROM `" . TABLE_PANEL_ACTIVATION . "`
 					WHERE `activationcode` = :activationcode"
 				);
 				$result = Database::pexecute_first($stmt, array("activationcode" => $activationcode));
-				
+
 				if ($result !== false) {
 					if ($result['admin'] == 1) {
 						$new_password = validate($_POST['new_password'], 'new password');
@@ -447,12 +502,12 @@ if ($action == 'resetpwd') {
 						$new_password = validatePassword($_POST['new_password'], 'new password');
 						$new_password_confirm = validatePassword($_POST['new_password_confirm'], 'new password confirm');
 					}
-					
+
 					if ($new_password == '') {
 						$message = $new_password;
-					} elseif($new_password_confirm == '') {
+					} elseif ($new_password_confirm == '') {
 						$message = $new_password_confirm;
-					} elseif($new_password != $new_password_confirm) {
+					} elseif ($new_password != $new_password_confirm) {
 						$message = $new_password . " != " . $new_password_confirm;
 					} else {
 						// Update user password
@@ -467,30 +522,30 @@ if ($action == 'resetpwd') {
 								WHERE `customerid` = :userid"
 							);
 						}
-						Database::pexecute($stmt, array("newpassword" => md5($new_password), "userid" => $result['userid']));
-						
-						$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => 'password_reset'), $settings);
+						Database::pexecute($stmt, array("newpassword" => makeCryptPassword($new_password), "userid" => $result['userid']));
+
+						$rstlog = FroxlorLogger::getInstanceOf(array('loginname' => 'password_reset'));
 						$rstlog->logAction(USR_ACTION, LOG_NOTICE, "changed password using password reset.");
-						
+
 						// Remove activation code from DB
 						$stmt = Database::prepare("DELETE FROM `" . TABLE_PANEL_ACTIVATION . "`
 							WHERE `activationcode` = :activationcode
 							AND `userid` = :userid"
 						);
 						Database::pexecute($stmt, array("activationcode" => $activationcode, "userid" => $result['userid']));
-						redirectTo('index.php', array("showmessage" => '6'), true);
+						redirectTo('index.php', array("showmessage" => '6'));
 					}
 				} else {
-					redirectTo('index.php', array("showmessage" => '7'), true);
+					redirectTo('index.php', array("showmessage" => '7'));
 				}
 			}
-			
+
 			eval("echo \"" . getTemplate('rpwd') . "\";");
-			
+
 		} else {
-			redirectTo('index.php', array("showmessage" => '7'), true);
+			redirectTo('index.php', array("showmessage" => '7'));
 		}
-		
+
 	} else {
 		redirectTo('index.php');
 	}
