@@ -83,6 +83,7 @@ class phpinterface_fpm {
 				'error_log',
 				'gpc_order',
 				'max_input_time',
+				'max_input_vars',
 				'memory_limit',
 				'open_basedir',
 				'output_buffering',
@@ -269,7 +270,7 @@ class phpinterface_fpm {
 				$is = explode("=", $inisection);
 				foreach ($this->_ini as $sec => $possibles) {
 					if (in_array(trim($is[0]), $possibles)) {
-						// check explictly for open_basedir
+						// check explicitly for open_basedir
 						if (trim($is[0]) == 'open_basedir' && $openbasedir == '') {
 							continue;
 						}
