@@ -12,46 +12,42 @@
  * @author     Froxlor team <team@froxlor.org> (2010-)
  * @license    GPLv2 http://files.froxlor.org/misc/COPYING.txt
  * @package    Functions
- * @version    $Id$
+ *
  */
 
 /**
  * chowns either awstats or webalizer folder,
  * either with webserver-user or - if fcgid
  * is used - the customers name, #258
- * 
+ *
  * @param array $row array if panel_customers
- * 
+ *
  * @return void
  */
-function makeChownWithNewStats($row)
-{
-	global $settings;
+function makeChownWithNewStats($row) {
 
 	// get correct user
-	if($settings['system']['mod_fcgid'] == 1)
-	{
+	if ((Settings::Get('system.mod_fcgid') == '1' || Settings::Get('phpfpm.enabled') == '1')
+		&& isset($row['deactivated'])
+		&& $row['deactivated'] == '0'
+	) {
 		$user = $row['loginname'];
 		$group = $row['loginname'];
-	}
-	else
-	{
+	} else {
 		$user = $row['guid'];
 		$group = $row['guid'];
 	}
 
 	// get correct directory
 	$dir = $row['documentroot'];
-	if($settings['system']['awstats_enabled'] == '1')
-	{
+	if (Settings::Get('system.awstats_enabled') == '1') {
 		$dir .= '/awstats/';
 	} else {
 		$dir .= '/webalizer/';
 	}
 
 	// only run chown if directory exists
-	if (file_exists($dir))
-	{
+	if (file_exists($dir)) {
 		// run chown
 		safe_exec('chown -R '.escapeshellarg($user).':'.escapeshellarg($group).' '.escapeshellarg(makeCorrectDir($dir)));
 	}
