@@ -269,9 +269,6 @@ $lng['admin']['deactivated_user'] = 'Gebruiker deactiveren';
 $lng['admin']['sendpassword'] = 'Verstuur wachtwoord';
 $lng['admin']['ownvhostsettings'] = 'Eigen vHost-Instellingen';
 $lng['admin']['configfiles']['serverconfiguration'] = 'Configuratie';
-$lng['admin']['configfiles']['files'] = '<b>Configuratiebestanden:</b> Wijzig de volgende bestanden of maak ze aan met<br />de volgende inhoud als u dit nog niet gedaan heeft.<br /><b>Let Op:</b> Het MySQL-wachtwoord is niet aangepast vanwege beveiligings overwegingen.<br />Vervang "MYSQL_PASSWORD" zelf. Als u uw MYSQl wachtwoord vergeten bent<br />kunt u het terugvinden in "lib/userdata.inc.php".';
-$lng['admin']['configfiles']['commands'] = '<b>Commando\'s:</b> Start de volgende commando\'s in een shell.';
-$lng['admin']['configfiles']['restart'] = '<b>Herstarten:</b> Start de volgende commando\'s in een shell zodat de configuratie opnieuw geladen wordt.';
 $lng['admin']['templates']['templates'] = 'Sjablonen';
 $lng['admin']['templates']['template_add'] = 'Maak sjabloon';
 $lng['admin']['templates']['template_edit'] = 'Bewerk sjabloon';
