@@ -297,9 +297,6 @@ $lng['admin']['deactivated_user'] = 'Desativar usuário';
 $lng['admin']['sendpassword'] = 'Enviar senha';
 $lng['admin']['ownvhostsettings'] = 'Own vHost-Settings';
 $lng['admin']['configfiles']['serverconfiguration'] = 'Configurações';
-$lng['admin']['configfiles']['files'] = '<b>Configfiles:</b> Por favor altere os seguintes arquivos ou crie eles com<br />o seguinte conteúdo se ele não existir.<br /><b>Por favor observe:</b> A senha do MySQL não foi alterada por razões de segurança.<br />Por favor substitua "MYSQL_PASSWORD" por uma sua. Se você esqueceu a senha do MySQL<br />você pode verificar em "lib/userdata.inc.php".';
-$lng['admin']['configfiles']['commands'] = '<b>Commands:</b> Por favor execute as seguintes comandos no shell.';
-$lng['admin']['configfiles']['restart'] = '<b>Restart:</b> Por favor execute as seguintes comandos no shell para carregar aas novas configurações.';
 $lng['admin']['templates']['templates'] = 'Templates';
 $lng['admin']['templates']['template_add'] = 'Adicionar template';
 $lng['admin']['templates']['template_edit'] = 'Editar template';
