@@ -19,39 +19,40 @@
 
 function awstatsDoSingleDomain($domain, $outputdir) {
 
-	global $cronlog, $settings, $theme;
+	global $cronlog, $theme;
 	$returnval = 0;
 
-	$domainconfig = makeCorrectFile($settings['system']['awstats_conf'].'/awstats.' . $domain . '.conf');
+	$domainconfig = makeCorrectFile(Settings::Get('system.awstats_conf').'/awstats.' . $domain . '.conf');
 
 	if (file_exists($domainconfig)) {
 
-		$outputdir = makeCorrectDir($outputdir . '/' . $domain);
+		$outputdir       = makeCorrectDir($outputdir . '/' . $domain);
+		$staticOutputdir = makeCorrectDir($outputdir . '/' . date('Y') . '-' . date('m'));
 
-		if (!is_dir($outputdir)) {
-			safe_exec('mkdir -p ' . escapeshellarg($outputdir));
+		if (!is_dir($staticOutputdir)) {
+			safe_exec('mkdir -p ' . escapeshellarg($staticOutputdir));
 		}
 
 		//check for correct path of awstats_buildstaticpages.pl
-		$awbsp = makeCorrectFile($settings['system']['awstats_path'].'/awstats_buildstaticpages.pl');
-		$awprog = makeCorrectFile($settings['system']['awstats_awstatspath'].'/awstats.pl');
-		
+		$awbsp = makeCorrectFile(Settings::Get('system.awstats_path').'/awstats_buildstaticpages.pl');
+		$awprog = makeCorrectFile(Settings::Get('system.awstats_awstatspath').'/awstats.pl');
+
 		if (!file_exists($awbsp)) {
 			echo "WANRING: Necessary awstats_buildstaticpages.pl script could not be found, no traffic is being calculated and no stats are generated. Please check your AWStats-Path setting";
 			$cronlog->logAction(CRON_ACTION, LOG_WARNING, "Necessary awstats_buildstaticpages.pl script could not be found, no traffic is being calculated and no stats are generated. Please check your AWStats-Path setting");
-			exit;	
+			exit;
 		}
 
-		$cronlog->logAction(CRON_ACTION, LOG_INFO, "Running awstats_buildstaticpages.pl for domain '".$domain."' (Output: '".$outputdir."')");
-		safe_exec($awbsp.' -awstatsprog='.escapeshellarg($awprog).' -update -month=' . date('n') . ' -year=' . date('Y') . ' -config=' . $domain . ' -dir='.escapeshellarg($outputdir));
-		
-		// index file is saved like 'awstats.[domain].html',
-		// so link a index.html to it
-		$original_index = makeCorrectFile($outputdir.'/awstats.'.$domain.'.html');
-		$new_index = makeCorrectFile($outputdir.'/index.html');
-		if (!file_exists($new_index)) {
-			safe_exec('ln -s '.escapeshellarg($original_index).' '.escapeshellarg($new_index));
-		}
+		$cronlog->logAction(CRON_ACTION, LOG_INFO, "Running awstats_buildstaticpages.pl for domain '".$domain."' (Output: '".$staticOutputdir."')");
+		safe_exec($awbsp.' -awstatsprog='.escapeshellarg($awprog).' -update -month=' . date('m') . ' -year=' . date('Y') . ' -config=' . $domain . ' -dir='.escapeshellarg($staticOutputdir));
+
+		// update our awstats index files
+		awstatsGenerateIndex($domain, $outputdir);
+
+		// the default selection is 'current',
+		// so link the latest dir to it
+		$new_current = makeCorrectFile($outputdir . '/current');
+		safe_exec('ln -fTs ' . escapeshellarg($staticOutputdir) . ' ' . escapeshellarg($new_current));
 
 		//statistics file looks like: 'awstats[month][year].[domain].txt'
 		$file = makeCorrectFile($outputdir.'/awstats'.date('mY', time()).'.'.$domain.'.txt');
@@ -62,7 +63,7 @@ function awstatsDoSingleDomain($domain, $outputdir) {
 			$content = @file_get_contents($file);
 			if ($content !== false) {
 				$content_array = explode("\n", $content);
-				
+
 				$count_bdw = false;
 				foreach ($content_array as $line) {
 					// skip empty lines and comments
@@ -97,6 +98,84 @@ function awstatsDoSingleDomain($domain, $outputdir) {
 	return $returnval;
 }
 
+
+function awstatsGenerateIndex($domain, $outputdir) {
+
+	// Generation header
+	$header  = "<!-- GENERATED BY FROXLOR -->\n";
+
+	// Looking for {year}-{month} directories
+	$entries = array();
+	foreach (scandir($outputdir) as $a) {
+		if (is_dir(makeCorrectDir($outputdir . '/' . $a)) && preg_match('/^[0-9]{4}-[0-9]{2}$/', $a)) {
+			array_push($entries, '<option value="' . $a . '">' . $a . '</option>');
+		}
+	}
+
+	// These are the variables we will replace
+	$regex = array(
+		'/\{SITE_DOMAIN\}/',
+		'/\{SELECT_ENTRIES\}/'
+	);
+
+	$replace = array(
+		$domain,
+		implode($entries)
+	);
+
+	// File names
+	$index_file = FROXLOR_INSTALL_DIR.'/templates/misc/awstats/index.html';
+	$index_file = makeCorrectFile($index_file);
+	$nav_file   = FROXLOR_INSTALL_DIR.'/templates/misc/awstats/nav.html';
+	$nav_file   = makeCorrectFile($nav_file);
+
+	// Write the index file
+	{
+		// 'index.html' used to be a symlink
+		unlink(makeCorrectFile($outputdir . '/' . 'index.html'));
+
+		$awstats_index_file = fopen(makeCorrectFile($outputdir . '/' . 'index.html'), 'w');
+		$awstats_index_tpl  = fopen($index_file, 'r');
+
+		// Write the header
+		fwrite($awstats_index_file, $header);
+
+		// Write the configuration file
+		while (($line = fgets($awstats_index_tpl, 4096)) !== false) {
+			if (!preg_match('/^#/', $line)
+			   && trim($line) != ''
+			) {
+				fwrite($awstats_index_file, preg_replace($regex, $replace, $line));
+			}
+		}
+		fclose($awstats_index_file);
+		fclose($awstats_index_tpl);
+	}
+
+	// Write the nav file
+	{
+		$awstats_nav_file = fopen(makeCorrectFile($outputdir . '/' . 'nav.html'), 'w');
+		$awstats_nav_tpl  = fopen($nav_file, 'r');
+
+		// Write the header
+		fwrite($awstats_nav_file, $header);
+
+		// Write the configuration file
+		while (($line = fgets($awstats_nav_tpl, 4096)) !== false) {
+			if (!preg_match('/^#/', $line)
+			   && trim($line) != ''
+			) {
+				fwrite($awstats_nav_file, preg_replace($regex, $replace, $line));
+			}
+		}
+		fclose($awstats_nav_file);
+		fclose($awstats_nav_tpl);
+	}
+
+	return;
+}
+
+
 function callAwstatsGetTraffic($customerid, $outputdir, $usersdomainlist) {
 
 	global $cronlog;
@@ -146,6 +225,7 @@ function callAwstatsGetTraffic($customerid, $outputdir, $usersdomainlist) {
 	return floatval($returnval);
 }
 
+
 /**
  * Function which make webalizer statistics and returns used traffic since last run
  *
@@ -157,11 +237,11 @@ function callAwstatsGetTraffic($customerid, $outputdir, $usersdomainlist) {
  */
 function callWebalizerGetTraffic($logfile, $outputdir, $caption, $usersdomainlist) {
 
-	global $settings, $cronlog;
+	global $cronlog;
 
 	$returnval = 0;
 
-	$logfile = makeCorrectFile($settings['system']['logfiles_directory'] . $logfile . '-access.log');
+	$logfile = makeCorrectFile(Settings::Get('system.logfiles_directory') . $logfile . '-access.log');
 	if (file_exists($logfile)) {
 		$domainargs = '';
 		foreach ($usersdomainlist as $domainid => $domain) {
@@ -185,14 +265,14 @@ function callWebalizerGetTraffic($logfile, $outputdir, $caption, $usersdomainlis
 		}
 
 		$verbosity = '';
-		if ($settings['system']['webalizer_quiet'] == '1') {
+		if (Settings::Get('system.webalizer_quiet') == '1') {
 			$verbosity = '-q';
-		} elseif($settings['system']['webalizer_quiet'] == '2') {
+		} elseif (Settings::Get('system.webalizer_quiet') == '2') {
 			$verbosity = '-Q';
 		}
 
 		$we = '/usr/bin/webalizer';
-		
+
 		// FreeBSD uses other paths, #140
 		if (!file_exists($we)) {
 			$we = '/usr/local/bin/webalizer';
@@ -267,7 +347,7 @@ function callWebalizerGetTraffic($logfile, $outputdir, $caption, $usersdomainlis
 			foreach ($months as $month => $traffic) {
 				if (!isset($httptrafficlast[$year][$month])) {
 					$returnval+= $traffic;
-				} elseif($httptrafficlast[$year][$month] < $httptraffic[$year][$month]) {
+				} elseif ($httptrafficlast[$year][$month] < $httptraffic[$year][$month]) {
 					$returnval+= ($httptraffic[$year][$month] - $httptrafficlast[$year][$month]);
 				}
 			}
